# Soarer Converter's configuration for IBM Model F122 (P/Ns 6110345,
# 6110668, 6111041, etcetera) and M122 (P/Ns 1390702, 1390876, 1393656,
# 1394167, 1395660, etcetera) keyboards.
#
# NOTE: the M122 "PC battlecruiser" hybrid terminal/PC keyboard (P/N
# 1397000) SHOULD work flawlessly with this configuration as-is, but this
# has not been tested yet.
#
# Additions:
# - Tailored mappings to make the keyboard behave as a regular full-size.
# - Volume controls on Caps Lock.
# - Print Screen enhancements.
# - Tailored numpad.
# - Hexapad.
# - CONSTANT_NAMES_MODE.
#
# Author:  Miguel Farah.
# Date:    20200919.
# Version: 2.1.
# See:     http://www.farah.cl/SoarersConverterConfigFiles/
#
##### BEGIN ########

macroblock

include "Volume-CapsLock.inc"

include "PrtScr-enhancements.inc"

include "Constant-names_toggler.inc"

  # Backtab (Shift-Tab, actually) - right to the left of Tab.
  macro EXTRA_F4
    PUSH_META SET_META lshift
    PRESS TAB
    POP_ALL_META
  endmacro

  # Alt-PrtScr in a single keystroke - this is actually quite more
  # convenient than what would be expected at a first glance.
  macro EXTRA_F6
    PUSH_META CLEAR_META all
    MAKE LALT
    PRESS PRINTSCREEN
    BREAK LALT
    POP_ALL_META
  endmacro

  # On my M122, some Ctrl-Alt-arrow combinations don't register as would be
  # expected (remember that in terminals keyboards, the keys "Reset" and
  # "Enter" in the bottom row are not meant to be modifiers in the first
  # place). I use those combinations a lot, so I need to wade around that
  # problem.
  #
  # This issue does not exist on the F122, but this key assignment actually
  # is pretty comfortable for a few other uses, so I've kept it for all.
  macro EXTRA_F10
    PUSH_META SET_META rctrl lalt
    onbreak norestoremeta
    POP_META
  endmacro

  # Num Lock needs to be available, but doesn't deserve an assignment in
  # the base layer.
  macro SCROLL_LOCK shift -ctrl -alt
    PUSH_META CLEAR_META shift
    PRESS NUM_LOCK
    POP_META
  endmacro

  # Hexapad toggler (see below).
  macro SCROLL_LOCK alt -shift -ctrl
    PUSH_META CLEAR_META all
    PRESS SELECT_1
    POP_ALL_META
  endmacro

  # The macro that produces the equals sign is defined here. Keep ONE of
  # those entries active and the others commented out, IN ACCORDANCE WITH
  # THE NATIONAL LAYOUT BEING USED (or make a new .inc, if the need should
  # arise). Each .inc file lists the national layouts it's fit for.
# include "Equals-Belgian.inc"
# include "Equals-Dutch.inc"
# include "Equals-English-Dvorak.inc"
# include "Equals-English.inc"
  include "Equals-European.inc"

endblock


remapblock

# Left-side function keys.
  EXTRA_F1      LGUI                # "Windows" key. "APP" is the Menu key.
  EXTRA_F2      ESC
  EXTRA_F3      PAUSE
# EXTRA_F4      (see macro above)
  EXTRA_F5      PRINTSCREEN
# EXTRA_F6      (see macro above)
# EXTRA_F7      UNASSIGNED          # This key is available.
# EXTRA_F8      UNASSIGNED          # This key is available.
  EXTRA_F9      MEDIA_MUTE
# EXTRA_F10     (see macro above)

# Main alphanumeric block.
  EUROPE_1      BACKSLASH           # This mapping is non-negotiable.

# Top-side extra function keys.
# F13           MEDIA_PLAY_PAUSE    # As it turns out, I barely used these
# F14           MEDIA_PREV_TRACK    # four, so I freed the keys to use them
# F15           MEDIA_NEXT_TRACK    # on my text editor as regular function
# F16           MEDIA_STOP          # keys. Uncomment and change as needed.
# F17
# F18
# F19
# F20
# F21
# F22
# F23
# F24

# Navigation cluster; only the "Rule" key needs to be remapped.
  LANG_4        SCROLL_LOCK         # Some people HATE Scroll Lock being
                                    # placed here. Don't be afraid to place
                                    # it elsewhere if that's what you want.

# Numpad.
#
# In the default layer, the gray keys are made to behave as they do in a
# regular full-sized keyboard, EXCEPT: a) the top left key outputs the
# equals sign instead of becoming the NumLock key; b) battleships have two
# 1U keys instead of a single 2U plus key - of those, the top one remains
# plus and the bottom key outputs a comma.
#
  ESC           PAD_EQUALS  # Equals sign - see the (included) macro above.
  NUM_LOCK      PAD_SLASH
  SCROLL_LOCK   PAD_ASTERIX
  EXTRA_SYSRQ   PAD_MINUS
  PAD_ASTERIX   PAD_PLUS
  PAD_MINUS     COMMA
  PAD_PLUS      PAD_ENTER

# COMMA assignment: Microsoft's keyboard layout tables do NOT include the
# PAD_COMMA (just as they ignore PAD_EQUALS); using (plain) COMMA instead
# of a macro has the added bonus of making Shift-PAD_MINUS produce the same
# output as Shift-COMMA (as it conveniently happens, in my national layout
# this outputs ';').

endblock


# Layer 1 changes the numpad into a hexapad (0..9, A..F, Enter and colon).

ifselect 1
macroblock

  # The macro that produces the colon is defined here. Keep ONE of those
  # entries active and the others commented out, IN ACCORDANCE WITH THE
  # NATIONAL LAYOUT BEING USED (or make a new .inc, if the need should
  # arise). Each .inc file lists the national layouts it's fit for.
# include "Colon-Brazilian.inc"
# include "Colon-English-Colemak.inc"
# include "Colon-English-Dvorak.inc"
# include "Colon-English.inc"
  include "Colon-European.inc"
# include "Colon-French.inc"

endblock

remapblock
  ESC           A
  NUM_LOCK      B
  SCROLL_LOCK   C
  EXTRA_SYSRQ   D
  PAD_ASTERIX   E
  PAD_MINUS     F
  PAD_PERIOD    AUX1    # Colon - see the (included) macro above.
endblock


include "Constant-names_layer.inc"

##### END ##########

